@@ -16,9 +16,9 @@
 import os
 import re
 import textwrap
+from configparser import ConfigParser
 
 from yapf.yapflib import errors
-from yapf.yapflib import py3compat
 
 
 class StyleConfigError(errors.YapfError):
@@ -235,7 +235,8 @@ _STYLE_HELP = dict(
     SPACES_AROUND_DEFAULT_OR_NAMED_ASSIGN=textwrap.dedent("""\
       Use spaces around default or named assigns."""),
     SPACES_AROUND_DICT_DELIMITERS=textwrap.dedent("""\
-      Adds a space after the opening '{' and before the ending '}' dict delimiters.
+      Adds a space after the opening '{' and before the ending '}' dict
+      delimiters.
 
         {1: 2}
 
@@ -244,7 +245,8 @@ _STYLE_HELP = dict(
         { 1: 2 }
       """),
     SPACES_AROUND_LIST_DELIMITERS=textwrap.dedent("""\
-      Adds a space after the opening '[' and before the ending ']' list delimiters.
+      Adds a space after the opening '[' and before the ending ']' list
+      delimiters.
 
         [1, 2]
 
@@ -258,7 +260,8 @@ _STYLE_HELP = dict(
         my_list[1 : 10 : 2]
       """),
     SPACES_AROUND_TUPLE_DELIMITERS=textwrap.dedent("""\
-      Adds a space after the opening '(' and before the ending ')' tuple delimiters.
+      Adds a space after the opening '(' and before the ending ')' tuple
+      delimiters.
 
         (1, 2, 3)
 
@@ -280,7 +283,8 @@ _STYLE_HELP = dict(
 
       will be formatted as:
 
-        1 + 1     # Adding values <-- 5 spaces between the end of the statement and comment
+        1 + 1     # Adding values <-- 5 spaces between the end of the
+                  # statement and comment
 
       With spaces_before_comment=15, 20:
 
@@ -295,16 +299,18 @@ _STYLE_HELP = dict(
 
       will be formatted as:
 
-        1 + 1          # Adding values <-- end of line comments in block aligned to col 15
+        1 + 1          # Adding values <-- end of line comments in block
+                       # aligned to col 15
         two + two      # More adding
 
-        longer_statement    # This is a longer statement <-- end of line comments in block aligned to col 20
+        longer_statement    # This is a longer statement <-- end of line
+                            # comments in block aligned to col 20
         short               # This is a shorter statement
 
         a_very_long_statement_that_extends_beyond_the_final_column  # Comment <-- the end of line comments are aligned based on the line length
         short                                                       # This is a shorter statement
 
-      """),
+      """),  # noqa
     SPLIT_ARGUMENTS_WHEN_COMMA_TERMINATED=textwrap.dedent("""\
       Split before arguments if the argument list is terminated by a
       comma."""),
@@ -339,7 +345,7 @@ _STYLE_HELP = dict(
 
         foo = ('This is a really long string: {}, {}, {}, {}'
                .format(a, b, c, d))
-      """),
+      """),  # noqa
     SPLIT_BEFORE_EXPRESSION_AFTER_OPENING_PAREN=textwrap.dedent("""\
       Split after the opening paren which surrounds an expression if it doesn't
       fit on a single line.
@@ -386,7 +392,7 @@ _STYLE_HELP = dict(
     SPLIT_PENALTY_EXCESS_CHARACTER=textwrap.dedent("""\
       The penalty for characters over the column limit."""),
     SPLIT_PENALTY_FOR_ADDED_LINE_SPLIT=textwrap.dedent("""\
-      The penalty incurred by adding a line split to the unwrapped line. The
+      The penalty incurred by adding a line split to the logical line. The
       more line splits added the higher the penalty."""),
     SPLIT_PENALTY_IMPORT_NAMES=textwrap.dedent("""\
       The penalty of splitting a list of "import as" names. For example:
@@ -399,7 +405,7 @@ _STYLE_HELP = dict(
 
         from a_very_long_or_indented_module_name_yada_yad import (
             long_argument_1, long_argument_2, long_argument_3)
-      """),
+      """),  # noqa
     SPLIT_PENALTY_LOGICAL_OPERATOR=textwrap.dedent("""\
       The penalty of splitting the line around the 'and' and 'or'
       operators."""),
@@ -418,7 +424,7 @@ def CreatePEP8Style():
       ALLOW_SPLIT_BEFORE_DEFAULT_OR_NAMED_ASSIGNS=True,
       ALLOW_SPLIT_BEFORE_DICT_VALUE=True,
       ARITHMETIC_PRECEDENCE_INDICATION=False,
-      BLANK_LINE_BEFORE_NESTED_CLASS_OR_DEF=False,
+      BLANK_LINE_BEFORE_NESTED_CLASS_OR_DEF=True,
       BLANK_LINE_BEFORE_CLASS_DOCSTRING=False,
       BLANK_LINE_BEFORE_MODULE_DOCSTRING=False,
       BLANK_LINES_AROUND_TOP_LEVEL_DEFINITION=2,
@@ -479,7 +485,6 @@ def CreateGoogleStyle():
   """Create the Google formatting style."""
   style = CreatePEP8Style()
   style['ALIGN_CLOSING_BRACKET_WITH_VISUAL_INDENT'] = False
-  style['BLANK_LINE_BEFORE_NESTED_CLASS_OR_DEF'] = True
   style['COLUMN_LIMIT'] = 80
   style['INDENT_DICTIONARY_VALUE'] = True
   style['INDENT_WIDTH'] = 4
@@ -511,6 +516,7 @@ def CreateFacebookStyle():
   """Create the Facebook formatting style."""
   style = CreatePEP8Style()
   style['ALIGN_CLOSING_BRACKET_WITH_VISUAL_INDENT'] = False
+  style['BLANK_LINE_BEFORE_NESTED_CLASS_OR_DEF'] = False
   style['COLUMN_LIMIT'] = 80
   style['DEDENT_CLOSING_BRACKETS'] = True
   style['INDENT_CLOSING_BRACKETS'] = False
@@ -568,12 +574,12 @@ def _StringSetConverter(s):
   """Option value converter for a comma-separated set of strings."""
   if len(s) > 2 and s[0] in '"\'':
     s = s[1:-1]
-  return set(part.strip() for part in s.split(','))
+  return {part.strip() for part in s.split(',')}
 
 
 def _BoolConverter(s):
   """Option value converter for a boolean."""
-  return py3compat.CONFIGPARSER_BOOLEAN_STATES[s.lower()]
+  return ConfigParser.BOOLEAN_STATES[s.lower()]
 
 
 def _IntListConverter(s):
@@ -696,7 +702,7 @@ def CreateStyleFromConfig(style_config):
 
   if isinstance(style_config, dict):
     config = _CreateConfigParserFromConfigDict(style_config)
-  elif isinstance(style_config, py3compat.basestring):
+  elif isinstance(style_config, str):
     style_factory = _STYLE_NAME_TO_FACTORY.get(style_config.lower())
     if style_factory is not None:
       return style_factory()
@@ -710,7 +716,7 @@ def CreateStyleFromConfig(style_config):
 
 
 def _CreateConfigParserFromConfigDict(config_dict):
-  config = py3compat.ConfigParser()
+  config = ConfigParser()
   config.add_section('style')
   for key, value in config_dict.items():
     config.set('style', key, str(value))
@@ -722,7 +728,7 @@ def _CreateConfigParserFromConfigString(config_string):
   if config_string[0] != '{' or config_string[-1] != '}':
     raise StyleConfigError(
         "Invalid style dict syntax: '{}'.".format(config_string))
-  config = py3compat.ConfigParser()
+  config = ConfigParser()
   config.add_section('style')
   for key, value, _ in re.findall(
       r'([a-zA-Z0-9_]+)\s*[:=]\s*'
@@ -740,18 +746,19 @@ def _CreateConfigParserFromConfigFile(config_filename):
     # Provide a more meaningful error here.
     raise StyleConfigError(
         '"{0}" is not a valid style or file path'.format(config_filename))
-  with open(config_filename) as style_file:
-    config = py3compat.ConfigParser()
-    if config_filename.endswith(PYPROJECT_TOML):
-      try:
-        import toml
-      except ImportError:
-        raise errors.YapfError(
-            "toml package is needed for using pyproject.toml as a configuration file"
-        )
+  config = ConfigParser()
 
-      pyproject_toml = toml.load(style_file)
-      style_dict = pyproject_toml.get("tool", {}).get("yapf", None)
+  if config_filename.endswith(PYPROJECT_TOML):
+    try:
+      import tomli as tomllib
+    except ImportError:
+      raise errors.YapfError(
+          'tomli package is needed for using pyproject.toml as a '
+          'configuration file')
+
+    with open(config_filename, 'rb') as style_file:
+      pyproject_toml = tomllib.load(style_file)
+      style_dict = pyproject_toml.get('tool', {}).get('yapf', None)
       if style_dict is None:
         raise StyleConfigError(
             'Unable to find section [tool.yapf] in {0}'.format(config_filename))
@@ -760,7 +767,9 @@ def _CreateConfigParserFromConfigFile(config_filename):
         config.set('style', k, str(v))
       return config
 
+  with open(config_filename) as style_file:
     config.read_file(style_file)
+
     if config_filename.endswith(SETUP_CONFIG):
       if not config.has_section('yapf'):
         raise StyleConfigError(
