@@ -23,10 +23,11 @@ import sys
 import tempfile
 import textwrap
 import unittest
+from io import StringIO
 
-from lib2to3.pgen2 import tokenize
+from yapf_third_party._ylib2to3.pgen2 import tokenize
 
-from yapf.yapflib import py3compat
+from yapf.yapflib import errors
 from yapf.yapflib import style
 from yapf.yapflib import yapf_api
 
@@ -62,11 +63,6 @@ class FormatCodeTest(yapf_test_helper.YAPFTest):
         """)
     self._Check(unformatted_code, expected_formatted_code)
 
-  def testPrintAfterPeriod(self):
-    unformatted_code = textwrap.dedent("""a.print\n""")
-    expected_formatted_code = textwrap.dedent("""a.print\n""")
-    self._Check(unformatted_code, expected_formatted_code)
-
 
 class FormatFileTest(unittest.TestCase):
 
@@ -87,15 +83,15 @@ class FormatFileTest(unittest.TestCase):
       self.fail(msg)
 
   def testFormatFile(self):
-    unformatted_code = textwrap.dedent(u"""\
+    unformatted_code = textwrap.dedent("""\
         if True:
          pass
         """)
-    expected_formatted_code_pep8 = textwrap.dedent(u"""\
+    expected_formatted_code_pep8 = textwrap.dedent("""\
         if True:
             pass
         """)
-    expected_formatted_code_yapf = textwrap.dedent(u"""\
+    expected_formatted_code_yapf = textwrap.dedent("""\
         if True:
           pass
         """)
@@ -107,7 +103,7 @@ class FormatFileTest(unittest.TestCase):
       self.assertCodeEqual(expected_formatted_code_yapf, formatted_code)
 
   def testDisableLinesPattern(self):
-    unformatted_code = textwrap.dedent(u"""\
+    unformatted_code = textwrap.dedent("""\
         if a:    b
 
         # yapf: disable
@@ -115,7 +111,7 @@ class FormatFileTest(unittest.TestCase):
 
         if h:    i
         """)
-    expected_formatted_code = textwrap.dedent(u"""\
+    expected_formatted_code = textwrap.dedent("""\
         if a: b
 
         # yapf: disable
@@ -128,7 +124,7 @@ class FormatFileTest(unittest.TestCase):
       self.assertCodeEqual(expected_formatted_code, formatted_code)
 
   def testDisableAndReenableLinesPattern(self):
-    unformatted_code = textwrap.dedent(u"""\
+    unformatted_code = textwrap.dedent("""\
         if a:    b
 
         # yapf: disable
@@ -137,7 +133,7 @@ class FormatFileTest(unittest.TestCase):
 
         if h:    i
         """)
-    expected_formatted_code = textwrap.dedent(u"""\
+    expected_formatted_code = textwrap.dedent("""\
         if a: b
 
         # yapf: disable
@@ -150,8 +146,31 @@ class FormatFileTest(unittest.TestCase):
       formatted_code, _, _ = yapf_api.FormatFile(filepath, style_config='pep8')
       self.assertCodeEqual(expected_formatted_code, formatted_code)
 
+  def testFmtOnOff(self):
+    unformatted_code = textwrap.dedent("""\
+        if a:    b
+
+        # fmt: off
+        if f:    g
+        # fmt: on
+
+        if h:    i
+        """)
+    expected_formatted_code = textwrap.dedent("""\
+        if a: b
+
+        # fmt: off
+        if f:    g
+        # fmt: on
+
+        if h: i
+        """)
+    with utils.TempFileContents(self.test_tmpdir, unformatted_code) as filepath:
+      formatted_code, _, _ = yapf_api.FormatFile(filepath, style_config='pep8')
+      self.assertCodeEqual(expected_formatted_code, formatted_code)
+
   def testDisablePartOfMultilineComment(self):
-    unformatted_code = textwrap.dedent(u"""\
+    unformatted_code = textwrap.dedent("""\
         if a:    b
 
         # This is a multiline comment that disables YAPF.
@@ -163,7 +182,7 @@ class FormatFileTest(unittest.TestCase):
         if h:    i
         """)
 
-    expected_formatted_code = textwrap.dedent(u"""\
+    expected_formatted_code = textwrap.dedent("""\
         if a: b
 
         # This is a multiline comment that disables YAPF.
@@ -178,7 +197,7 @@ class FormatFileTest(unittest.TestCase):
       formatted_code, _, _ = yapf_api.FormatFile(filepath, style_config='pep8')
       self.assertCodeEqual(expected_formatted_code, formatted_code)
 
-    code = textwrap.dedent(u"""\
+    code = textwrap.dedent("""\
       def foo_function():
           # some comment
           # yapf: disable
@@ -195,34 +214,34 @@ class FormatFileTest(unittest.TestCase):
       self.assertCodeEqual(code, formatted_code)
 
   def testEnabledDisabledSameComment(self):
-    code = textwrap.dedent(u"""\
+    code = textwrap.dedent("""\
         # yapf: disable
         a(bbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbb, ccccccccccccccccccccccccccccccc, ddddddddddddddddddddddd, eeeeeeeeeeeeeeeeeeeeeeeeeee)
         # yapf: enable
         # yapf: disable
         a(bbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbb, ccccccccccccccccccccccccccccccc, ddddddddddddddddddddddd, eeeeeeeeeeeeeeeeeeeeeeeeeee)
         # yapf: enable
-        """)
+        """)  # noqa
     with utils.TempFileContents(self.test_tmpdir, code) as filepath:
       formatted_code, _, _ = yapf_api.FormatFile(filepath, style_config='pep8')
       self.assertCodeEqual(code, formatted_code)
 
   def testFormatFileLinesSelection(self):
-    unformatted_code = textwrap.dedent(u"""\
+    unformatted_code = textwrap.dedent("""\
         if a:    b
 
         if f:    g
 
         if h:    i
         """)
-    expected_formatted_code_lines1and2 = textwrap.dedent(u"""\
+    expected_formatted_code_lines1and2 = textwrap.dedent("""\
         if a: b
 
         if f:    g
 
         if h:    i
         """)
-    expected_formatted_code_lines3 = textwrap.dedent(u"""\
+    expected_formatted_code_lines3 = textwrap.dedent("""\
         if a:    b
 
         if f: g
@@ -238,25 +257,22 @@ class FormatFileTest(unittest.TestCase):
       self.assertCodeEqual(expected_formatted_code_lines3, formatted_code)
 
   def testFormatFileDiff(self):
-    unformatted_code = textwrap.dedent(u"""\
+    unformatted_code = textwrap.dedent("""\
         if True:
          pass
         """)
     with utils.TempFileContents(self.test_tmpdir, unformatted_code) as filepath:
       diff, _, _ = yapf_api.FormatFile(filepath, print_diff=True)
-      self.assertIn(u'+  pass', diff)
+      self.assertIn('+  pass', diff)
 
   def testFormatFileInPlace(self):
-    unformatted_code = u'True==False\n'
-    formatted_code = u'True == False\n'
+    unformatted_code = 'True==False\n'
+    formatted_code = 'True == False\n'
     with utils.TempFileContents(self.test_tmpdir, unformatted_code) as filepath:
       result, _, _ = yapf_api.FormatFile(filepath, in_place=True)
       self.assertEqual(result, None)
       with open(filepath) as fd:
-        if sys.version_info[0] <= 2:
-          self.assertCodeEqual(formatted_code, fd.read().decode('ascii'))
-        else:
-          self.assertCodeEqual(formatted_code, fd.read())
+        self.assertCodeEqual(formatted_code, fd.read())
 
       self.assertRaises(
           ValueError,
@@ -266,17 +282,15 @@ class FormatFileTest(unittest.TestCase):
           print_diff=True)
 
   def testNoFile(self):
-    stream = py3compat.StringIO()
-    handler = logging.StreamHandler(stream)
-    logger = logging.getLogger('mylogger')
-    logger.addHandler(handler)
-    self.assertRaises(
-        IOError, yapf_api.FormatFile, 'not_a_file.py', logger=logger.error)
-    self.assertEqual(stream.getvalue(),
-                     "[Errno 2] No such file or directory: 'not_a_file.py'\n")
+    with self.assertRaises(IOError) as context:
+      yapf_api.FormatFile('not_a_file.py')
+
+    self.assertEqual(
+        str(context.exception),
+        "[Errno 2] No such file or directory: 'not_a_file.py'")
 
   def testCommentsUnformatted(self):
-    code = textwrap.dedent(u"""\
+    code = textwrap.dedent("""\
         foo = [# A list of things
                # bork
             'one',
@@ -288,7 +302,7 @@ class FormatFileTest(unittest.TestCase):
       self.assertCodeEqual(code, formatted_code)
 
   def testDisabledHorizontalFormattingOnNewLine(self):
-    code = textwrap.dedent(u"""\
+    code = textwrap.dedent("""\
         # yapf: disable
         a = [
         1]
@@ -299,12 +313,12 @@ class FormatFileTest(unittest.TestCase):
       self.assertCodeEqual(code, formatted_code)
 
   def testSplittingSemicolonStatements(self):
-    unformatted_code = textwrap.dedent(u"""\
+    unformatted_code = textwrap.dedent("""\
         def f():
           x = y + 42 ; z = n * 42
           if True: a += 1 ; b += 1; c += 1
         """)
-    expected_formatted_code = textwrap.dedent(u"""\
+    expected_formatted_code = textwrap.dedent("""\
         def f():
             x = y + 42
             z = n * 42
@@ -318,12 +332,12 @@ class FormatFileTest(unittest.TestCase):
       self.assertCodeEqual(expected_formatted_code, formatted_code)
 
   def testSemicolonStatementsDisabled(self):
-    unformatted_code = textwrap.dedent(u"""\
+    unformatted_code = textwrap.dedent("""\
         def f():
           x = y + 42 ; z = n * 42  # yapf: disable
           if True: a += 1 ; b += 1; c += 1
         """)
-    expected_formatted_code = textwrap.dedent(u"""\
+    expected_formatted_code = textwrap.dedent("""\
         def f():
             x = y + 42 ; z = n * 42  # yapf: disable
             if True:
@@ -336,7 +350,7 @@ class FormatFileTest(unittest.TestCase):
       self.assertCodeEqual(expected_formatted_code, formatted_code)
 
   def testDisabledSemiColonSeparatedStatements(self):
-    code = textwrap.dedent(u"""\
+    code = textwrap.dedent("""\
         # yapf: disable
         if True: a ; b
         """)
@@ -345,7 +359,7 @@ class FormatFileTest(unittest.TestCase):
       self.assertCodeEqual(code, formatted_code)
 
   def testDisabledMultilineStringInDictionary(self):
-    code = textwrap.dedent(u"""\
+    code = textwrap.dedent("""\
         # yapf: disable
 
         A = [
@@ -364,7 +378,7 @@ class FormatFileTest(unittest.TestCase):
       self.assertCodeEqual(code, formatted_code)
 
   def testDisabledWithPrecedingText(self):
-    code = textwrap.dedent(u"""\
+    code = textwrap.dedent("""\
         # TODO(fix formatting): yapf: disable
 
         A = [
@@ -383,7 +397,7 @@ class FormatFileTest(unittest.TestCase):
       self.assertCodeEqual(code, formatted_code)
 
   def testCRLFLineEnding(self):
-    code = u'class _():\r\n  pass\r\n'
+    code = 'class _():\r\n  pass\r\n'
     with utils.TempFileContents(self.test_tmpdir, code) as filepath:
       formatted_code, _, _ = yapf_api.FormatFile(filepath, style_config='yapf')
       self.assertCodeEqual(code, formatted_code)
@@ -428,19 +442,8 @@ class CommandLineTest(unittest.TestCase):
     self.assertEqual(stderrdata, b'')
     self.assertMultiLineEqual(reformatted_code.decode('utf-8'), expected)
 
-  def testUnicodeEncodingPipedToFile(self):
-    unformatted_code = textwrap.dedent(u"""\
-        def foo():
-            print('⇒')
-        """)
-    with utils.NamedTempFile(
-        dirname=self.test_tmpdir, suffix='.py') as (out, _):
-      with utils.TempFileContents(
-          self.test_tmpdir, unformatted_code, suffix='.py') as filepath:
-        subprocess.check_call(YAPF_BINARY + ['--diff', filepath], stdout=out)
-
   def testInPlaceReformatting(self):
-    unformatted_code = textwrap.dedent(u"""\
+    unformatted_code = textwrap.dedent("""\
         def foo():
           x = 37
         """)
@@ -457,8 +460,8 @@ class CommandLineTest(unittest.TestCase):
     self.assertEqual(reformatted_code, expected_formatted_code)
 
   def testInPlaceReformattingBlank(self):
-    unformatted_code = u'\n\n'
-    expected_formatted_code = u'\n'
+    unformatted_code = '\n\n'
+    expected_formatted_code = '\n'
     with utils.TempFileContents(
         self.test_tmpdir, unformatted_code, suffix='.py') as filepath:
       p = subprocess.Popen(YAPF_BINARY + ['--in-place', filepath])
@@ -467,9 +470,9 @@ class CommandLineTest(unittest.TestCase):
         reformatted_code = fd.read()
     self.assertEqual(reformatted_code, expected_formatted_code)
 
-  def testInPlaceReformattingEmpty(self):
-    unformatted_code = u''
-    expected_formatted_code = u''
+  def testInPlaceReformattingWindowsNewLine(self):
+    unformatted_code = '\r\n\r\n'
+    expected_formatted_code = '\r\n'
     with utils.TempFileContents(
         self.test_tmpdir, unformatted_code, suffix='.py') as filepath:
       p = subprocess.Popen(YAPF_BINARY + ['--in-place', filepath])
@@ -478,6 +481,41 @@ class CommandLineTest(unittest.TestCase):
         reformatted_code = fd.read()
     self.assertEqual(reformatted_code, expected_formatted_code)
 
+  def testInPlaceReformattingNoNewLine(self):
+    unformatted_code = textwrap.dedent('def foo(): x = 37')
+    expected_formatted_code = textwrap.dedent("""\
+        def foo():
+            x = 37
+        """)
+    with utils.TempFileContents(
+        self.test_tmpdir, unformatted_code, suffix='.py') as filepath:
+      p = subprocess.Popen(YAPF_BINARY + ['--in-place', filepath])
+      p.wait()
+      with io.open(filepath, mode='r', newline='') as fd:
+        reformatted_code = fd.read()
+    self.assertEqual(reformatted_code, expected_formatted_code)
+
+  def testInPlaceReformattingEmpty(self):
+    unformatted_code = ''
+    expected_formatted_code = ''
+    with utils.TempFileContents(
+        self.test_tmpdir, unformatted_code, suffix='.py') as filepath:
+      p = subprocess.Popen(YAPF_BINARY + ['--in-place', filepath])
+      p.wait()
+      with io.open(filepath, mode='r', encoding='utf-8', newline='') as fd:
+        reformatted_code = fd.read()
+    self.assertEqual(reformatted_code, expected_formatted_code)
+
+  def testPrintModified(self):
+    for unformatted_code, has_change in [('1==2', True), ('1 == 2', False)]:
+      with utils.TempFileContents(
+          self.test_tmpdir, unformatted_code, suffix='.py') as filepath:
+        output = subprocess.check_output(
+            YAPF_BINARY + ['--in-place', '--print-modified', filepath],
+            text=True)
+        check = self.assertIn if has_change else self.assertNotIn
+        check(f'Formatted {filepath}', output)
+
   def testReadFromStdin(self):
     unformatted_code = textwrap.dedent("""\
         def foo():
@@ -521,7 +559,7 @@ class CommandLineTest(unittest.TestCase):
         def foo():    # trail
           x = 37
         """)
-    style_file = textwrap.dedent(u'''\
+    style_file = textwrap.dedent('''\
         [style]
         based_on_style = yapf
         spaces_before_comment = 4
@@ -540,8 +578,8 @@ class CommandLineTest(unittest.TestCase):
     expected_formatted_code = textwrap.dedent("""\
         a_very_long_statement_that_extends_way_beyond # Comment
         short                                         # This is a shorter statement
-        """)
-    style_file = textwrap.dedent(u'''\
+        """)  # noqa
+    style_file = textwrap.dedent('''\
         [style]
         spaces_before_comment = 15, 20
         ''')
@@ -561,7 +599,7 @@ class CommandLineTest(unittest.TestCase):
     self.assertYapfReformats(unformatted_code, expected_formatted_code)
 
   def testEncodingVerification(self):
-    unformatted_code = textwrap.dedent(u"""\
+    unformatted_code = textwrap.dedent("""\
         '''The module docstring.'''
         # -*- coding: utf-8 -*-
         def f():
@@ -576,7 +614,7 @@ class CommandLineTest(unittest.TestCase):
           subprocess.check_call(YAPF_BINARY + ['--diff', filepath], stdout=out)
         except subprocess.CalledProcessError as e:
           # Indicates the text changed.
-          self.assertEqual(e.returncode, 1)  # pylint: disable=g-assert-in-except
+          self.assertEqual(e.returncode, 1)  # pylint: disable=g-assert-in-except # noqa
 
   def testReformattingSpecificLines(self):
     unformatted_code = textwrap.dedent("""\
@@ -588,7 +626,7 @@ class CommandLineTest(unittest.TestCase):
         def g():
             if (xxxxxxxxxxxx.yyyyyyyy(zzzzzzzzzzzzz[0]) == 'aaaaaaaaaaa' and xxxxxxxxxxxx.yyyyyyyy(zzzzzzzzzzzzz[0].mmmmmmmm[0]) == 'bbbbbbb'):
                 pass
-        """)
+        """)  # noqa
     expected_formatted_code = textwrap.dedent("""\
         def h():
             if (xxxxxxxxxxxx.yyyyyyyy(zzzzzzzzzzzzz[0]) == 'aaaaaaaaaaa' and
@@ -599,7 +637,7 @@ class CommandLineTest(unittest.TestCase):
         def g():
             if (xxxxxxxxxxxx.yyyyyyyy(zzzzzzzzzzzzz[0]) == 'aaaaaaaaaaa' and xxxxxxxxxxxx.yyyyyyyy(zzzzzzzzzzzzz[0].mmmmmmmm[0]) == 'bbbbbbb'):
                 pass
-        """)
+        """)  # noqa
     # TODO(ambv): the `expected_formatted_code` here is not PEP8 compliant,
     # raising "E129 visually indented line with same indent as next logical
     # line" with flake8.
@@ -639,7 +677,7 @@ class CommandLineTest(unittest.TestCase):
             if (xxxxxxxxxxxx.yyyyyyyy(zzzzzzzzzzzzz[0]) == 'aaaaaaaaaaa' and xxxxxxxxxxxx.yyyyyyyy(zzzzzzzzzzzzz[0].mmmmmmmm[0]) == 'bbbbbbb'):
                 pass
         # yapf: enable
-        """)
+        """)  # noqa
     expected_formatted_code = textwrap.dedent("""\
         def h():
             if (xxxxxxxxxxxx.yyyyyyyy(zzzzzzzzzzzzz[0]) == 'aaaaaaaaaaa' and
@@ -652,7 +690,7 @@ class CommandLineTest(unittest.TestCase):
             if (xxxxxxxxxxxx.yyyyyyyy(zzzzzzzzzzzzz[0]) == 'aaaaaaaaaaa' and xxxxxxxxxxxx.yyyyyyyy(zzzzzzzzzzzzz[0].mmmmmmmm[0]) == 'bbbbbbb'):
                 pass
         # yapf: enable
-        """)
+        """)  # noqa
     self.assertYapfReformats(unformatted_code, expected_formatted_code)
 
   def testReformattingSkippingToEndOfFile(self):
@@ -672,7 +710,7 @@ class CommandLineTest(unittest.TestCase):
                        xxxxxxxxxxxxxxxxxxxxx(yyyyyyyyyyyyy[zzzzz].aaaaaaaa[0]) ==
                        'bbbbbbb'):
                     pass
-        """)
+        """)  # noqa
     expected_formatted_code = textwrap.dedent("""\
         def h():
             if (xxxxxxxxxxxx.yyyyyyyy(zzzzzzzzzzzzz[0]) == 'aaaaaaaaaaa' and
@@ -691,7 +729,7 @@ class CommandLineTest(unittest.TestCase):
                        xxxxxxxxxxxxxxxxxxxxx(yyyyyyyyyyyyy[zzzzz].aaaaaaaa[0]) ==
                        'bbbbbbb'):
                     pass
-        """)
+        """)  # noqa
     self.assertYapfReformats(unformatted_code, expected_formatted_code)
 
   def testReformattingSkippingSingleLine(self):
@@ -703,7 +741,7 @@ class CommandLineTest(unittest.TestCase):
         def g():
             if (xxxxxxxxxxxx.yyyyyyyy(zzzzzzzzzzzzz[0]) == 'aaaaaaaaaaa' and xxxxxxxxxxxx.yyyyyyyy(zzzzzzzzzzzzz[0].mmmmmmmm[0]) == 'bbbbbbb'):  # yapf: disable
                 pass
-        """)
+        """)  # noqa
     expected_formatted_code = textwrap.dedent("""\
         def h():
             if (xxxxxxxxxxxx.yyyyyyyy(zzzzzzzzzzzzz[0]) == 'aaaaaaaaaaa' and
@@ -714,7 +752,7 @@ class CommandLineTest(unittest.TestCase):
         def g():
             if (xxxxxxxxxxxx.yyyyyyyy(zzzzzzzzzzzzz[0]) == 'aaaaaaaaaaa' and xxxxxxxxxxxx.yyyyyyyy(zzzzzzzzzzzzz[0].mmmmmmmm[0]) == 'bbbbbbb'):  # yapf: disable
                 pass
-        """)
+        """)  # noqa
     self.assertYapfReformats(unformatted_code, expected_formatted_code)
 
   def testDisableWholeDataStructure(self):
@@ -735,12 +773,14 @@ class CommandLineTest(unittest.TestCase):
   def testDisableButAdjustIndentations(self):
     unformatted_code = textwrap.dedent("""\
         class SplitPenaltyTest(unittest.TestCase):
+
           def testUnbreakable(self):
             self._CheckPenalties(tree, [
             ])  # yapf: disable
         """)
     expected_formatted_code = textwrap.dedent("""\
         class SplitPenaltyTest(unittest.TestCase):
+
             def testUnbreakable(self):
                 self._CheckPenalties(tree, [
                 ])  # yapf: disable
@@ -756,7 +796,7 @@ class CommandLineTest(unittest.TestCase):
         def g():
             if (xxxxxxxxxxxx.yyyyyyyy        (zzzzzzzzzzzzz  [0]) ==     'aaaaaaaaaaa' and    xxxxxxxxxxxx.yyyyyyyy(zzzzzzzzzzzzz[0].mmmmmmmm[0]) == 'bbbbbbb'):  # yapf: disable
                 pass
-        """)
+        """)  # noqa
     expected_formatted_code = textwrap.dedent("""\
         def h():
             if (xxxxxxxxxxxx.yyyyyyyy(zzzzzzzzzzzzz[0]) == 'aaaaaaaaaaa' and
@@ -767,7 +807,7 @@ class CommandLineTest(unittest.TestCase):
         def g():
             if (xxxxxxxxxxxx.yyyyyyyy        (zzzzzzzzzzzzz  [0]) ==     'aaaaaaaaaaa' and    xxxxxxxxxxxx.yyyyyyyy(zzzzzzzzzzzzz[0].mmmmmmmm[0]) == 'bbbbbbb'):  # yapf: disable
                 pass
-        """)
+        """)  # noqa
     self.assertYapfReformats(unformatted_code, expected_formatted_code)
 
   def testRetainingVerticalWhitespace(self):
@@ -782,7 +822,7 @@ class CommandLineTest(unittest.TestCase):
             if (xxxxxxxxxxxx.yyyyyyyy(zzzzzzzzzzzzz[0]) == 'aaaaaaaaaaa' and xxxxxxxxxxxx.yyyyyyyy(zzzzzzzzzzzzz[0].mmmmmmmm[0]) == 'bbbbbbb'):
 
                 pass
-        """)
+        """)  # noqa
     expected_formatted_code = textwrap.dedent("""\
         def h():
             if (xxxxxxxxxxxx.yyyyyyyy(zzzzzzzzzzzzz[0]) == 'aaaaaaaaaaa' and
@@ -795,7 +835,7 @@ class CommandLineTest(unittest.TestCase):
             if (xxxxxxxxxxxx.yyyyyyyy(zzzzzzzzzzzzz[0]) == 'aaaaaaaaaaa' and xxxxxxxxxxxx.yyyyyyyy(zzzzzzzzzzzzz[0].mmmmmmmm[0]) == 'bbbbbbb'):
 
                 pass
-        """)
+        """)  # noqa
     self.assertYapfReformats(
         unformatted_code,
         expected_formatted_code,
@@ -881,8 +921,6 @@ x = {
         """)
     expected_formatted_code = textwrap.dedent("""\
         a = line_to_format
-
-
         def f():
             x = y + 42; z = n * 42
             if True: a += 1 ; b += 1 ; c += 1
@@ -902,11 +940,9 @@ x = {
         <b>Residence: </b>"""+palace["Winter"]+"""<br>
         </body>
         </html>"""
-        ''')
+        ''')  # noqa
     expected_formatted_code = textwrap.dedent('''\
         foo = 42
-
-
         def f():
             email_text += """<html>This is a really long docstring that goes over the column limit and is multi-line.<br><br>
         <b>Czar: </b>"""+despot["Nicholas"]+"""<br>
@@ -914,7 +950,7 @@ x = {
         <b>Residence: </b>"""+palace["Winter"]+"""<br>
         </body>
         </html>"""
-        ''')
+        ''')  # noqa
     self.assertYapfReformats(
         unformatted_code,
         expected_formatted_code,
@@ -1010,7 +1046,7 @@ x = {
                                   'eeeeeeeeeeeeeeeeeeeeeeeee.%s' % c.ffffffffffff),
                                  gggggggggggg.hhhhhhhhh(c, c.ffffffffffff))
                 iiiii = jjjjjjjjjjjjjj.iiiii
-        """)
+        """)  # noqa
     self.assertYapfReformats(
         unformatted_code,
         expected_formatted_code,
@@ -1031,6 +1067,7 @@ x = {
             def aaaaaaaaaaaaa(self):
                 pass
 
+
             def bbbbbbbbbbbbb(self):  # 5
                 pass
         """)
@@ -1059,7 +1096,7 @@ x = {
                                   'eeeeeeeeeeeeeeeeeeeeeeeee.%s' % c.ffffffffffff),
                                  gggggggggggg.hhhhhhhhh(c, c.ffffffffffff))
                 iiiii = jjjjjjjjjjjjjj.iiiii
-        """)
+        """)  # noqa
     self.assertYapfReformats(
         unformatted_code,
         expected_formatted_code,
@@ -1129,7 +1166,7 @@ x = {
           first_argument_on_the_same_line, second_argument_makes_the_line_too_long
       ):
           pass
-    """)
+    """)  # noqa
     self.assertYapfReformats(
         unformatted_code,
         expected_formatted_fb_code,
@@ -1157,7 +1194,7 @@ x = {
        """)
     with utils.NamedTempFile(dirname=self.test_tmpdir, mode='w') as (f, name):
       f.write(
-          textwrap.dedent(u'''\
+          textwrap.dedent('''\
           [style]
           column_limit=82
           coalesce_brackets = True
@@ -1170,13 +1207,12 @@ x = {
 
   def testPseudoParenSpaces(self):
     unformatted_code = textwrap.dedent("""\
-        def foo():
+        def   foo():
           def bar():
             return {msg_id: author for author, msg_id in reader}
         """)
     expected_formatted_code = textwrap.dedent("""\
         def foo():
-
           def bar():
             return {msg_id: author for author, msg_id in reader}
         """)
@@ -1249,8 +1285,8 @@ def foo_function():
 def foo_function():
 	if True:
 		pass
-"""
-    style_contents = u"""\
+"""  # noqa: W191,E101
+    style_contents = """\
 [style]
 based_on_style = yapf
 USE_TABS = true
@@ -1273,8 +1309,8 @@ def f():
 	    'hello',
 	    'world',
 	]
-"""
-    style_contents = u"""\
+"""  # noqa: W191,E101
+    style_contents = """\
 [style]
 based_on_style = yapf
 USE_TABS = true
@@ -1298,8 +1334,8 @@ def foo_function(
 			'hello',
 			'world',
 	]
-"""
-    style_contents = u"""\
+"""  # noqa: W191,E101
+    style_contents = """\
 [style]
 based_on_style = yapf
 USE_TABS = true
@@ -1326,8 +1362,8 @@ def foo_function(arg1, arg2,
 			'hello',
 			'world',
 	]
-"""
-    style_contents = u"""\
+"""  # noqa: W191,E101
+    style_contents = """\
 [style]
 based_on_style = yapf
 USE_TABS = true
@@ -1355,7 +1391,7 @@ def foo_function(
             'world',
     ]
 """
-    style_contents = u"""\
+    style_contents = """\
 [style]
 based_on_style = yapf
 COLUMN_LIMIT=32
@@ -1382,7 +1418,7 @@ def foo_function(arg1, arg2,
             'world',
     ]
 """
-    style_contents = u"""\
+    style_contents = """\
 [style]
 based_on_style = yapf
 COLUMN_LIMIT=32
@@ -1482,31 +1518,29 @@ CONTINUATION_ALIGN_STYLE = valign-right
         expected_formatted_code,
         extra_options=['--style', 'yapf', '--lines', '1-1'])
 
-  @unittest.skipUnless(py3compat.PY36, 'Requires Python 3.6')
-  def testNoSpacesAroundBinaryOperators(self):
-    unformatted_code = """\
-a = 4-b/c@d**37
-"""
-    expected_formatted_code = """\
-a = 4-b / c@d**37
-"""
+  def testDisableWithLinesOption(self):
+    unformatted_code = textwrap.dedent("""\
+        # yapf_lines_bug.py
+        # yapf: disable
+        def outer_func():
+            def inner_func():
+                return
+            return
+        # yapf: enable
+        """)
+    expected_formatted_code = textwrap.dedent("""\
+        # yapf_lines_bug.py
+        # yapf: disable
+        def outer_func():
+            def inner_func():
+                return
+            return
+        # yapf: enable
+        """)
     self.assertYapfReformats(
         unformatted_code,
         expected_formatted_code,
-        extra_options=[
-            '--style',
-            '{based_on_style: pep8, '
-            'no_spaces_around_selected_binary_operators: "@,**,-"}',
-        ])
-
-  @unittest.skipUnless(py3compat.PY36, 'Requires Python 3.6')
-  def testCP936Encoding(self):
-    unformatted_code = 'print("中文")\n'
-    expected_formatted_code = 'print("中文")\n'
-    self.assertYapfReformats(
-        unformatted_code,
-        expected_formatted_code,
-        env={'PYTHONIOENCODING': 'cp936'})
+        extra_options=['--lines', '1-8'])
 
   def testDisableWithLineRanges(self):
     unformatted_code = """\
@@ -1538,11 +1572,11 @@ class BadInputTest(unittest.TestCase):
 
   def testBadSyntax(self):
     code = '  a = 1\n'
-    self.assertRaises(SyntaxError, yapf_api.FormatCode, code)
+    self.assertRaises(errors.YapfError, yapf_api.FormatCode, code)
 
   def testBadCode(self):
     code = 'x = """hello\n'
-    self.assertRaises(tokenize.TokenError, yapf_api.FormatCode, code)
+    self.assertRaises(errors.YapfError, yapf_api.FormatCode, code)
 
 
 class DiffIndentTest(unittest.TestCase):
@@ -1600,11 +1634,11 @@ class HorizontallyAlignedTrailingCommentsTest(yapf_test_helper.YAPFTest):
         """)
     expected_formatted_code = textwrap.dedent("""\
         foo = '1'     # Aligned at first list value
-        
+
         foo = '2__<15>'         # Aligned at second list value
-        
+
         foo = '3____________<25>'         # Aligned at third list value
-        
+
         foo = '4______________________<35>' # Aligned beyond list values
         """)
     self._Check(unformatted_code, expected_formatted_code)
@@ -1683,7 +1717,7 @@ class HorizontallyAlignedTrailingCommentsTest(yapf_test_helper.YAPFTest):
                                     # Line 6
 
                                             # Aligned with prev comment block
-        """)
+        """)  # noqa
     expected_formatted_code = textwrap.dedent("""\
         func(1)       # Line 1
         func(2)       # Line 2
@@ -1693,7 +1727,7 @@ class HorizontallyAlignedTrailingCommentsTest(yapf_test_helper.YAPFTest):
                       # Line 6
 
                       # Aligned with prev comment block
-        """)
+        """)  # noqa
     self._Check(unformatted_code, expected_formatted_code)
 
   def testBlockIndentedFuncSuffix(self):
@@ -1710,14 +1744,14 @@ class HorizontallyAlignedTrailingCommentsTest(yapf_test_helper.YAPFTest):
 
             def Func():
                 pass
-        """)
+        """)  # noqa
     expected_formatted_code = textwrap.dedent("""\
         if True:
             func(1)   # Line 1
             func(2)   # Line 2
                       # Line 3
             func(3)   # Line 4
-                      
+
             # Line 5 - SpliceComments makes this a new block
             # Line 6
 
@@ -1738,7 +1772,7 @@ class HorizontallyAlignedTrailingCommentsTest(yapf_test_helper.YAPFTest):
             func(3)                             # Line 4
                                                 # Line 5
                                                 # Line 6
-            
+
                                                 # Not aligned
         """)
     expected_formatted_code = textwrap.dedent("""\
@@ -1765,9 +1799,9 @@ class HorizontallyAlignedTrailingCommentsTest(yapf_test_helper.YAPFTest):
                     func(3)                             # Line 4
                                                         # Line 5
                                                         # Line 6
-                    
+
                                                         # Not aligned
-        """)
+        """)  # noqa
     expected_formatted_code = textwrap.dedent("""\
         if True:
             if True:
@@ -1778,7 +1812,7 @@ class HorizontallyAlignedTrailingCommentsTest(yapf_test_helper.YAPFTest):
                     func(3)     # Line 4
                                 # Line 5
                                 # Line 6
-        
+
                     # Not aligned
         """)
     self._Check(unformatted_code, expected_formatted_code)
@@ -1901,7 +1935,7 @@ class SpacesAroundDictTest(_SpacesAroundDictListTupleTestImpl):
       { 1: 2 }
       { k: v for k, v in other.items() }
       { k for k in [1, 2, 3] }
-      
+
       # The following statements should not change
       {}
       {1 : 2} # yapf: disable
@@ -1909,7 +1943,7 @@ class SpacesAroundDictTest(_SpacesAroundDictListTupleTestImpl):
       # yapf: disable
       {1 : 2}
       # yapf: enable
-      
+
       # Dict settings should not impact lists or tuples
       [1, 2]
       (3, 4)
@@ -1960,12 +1994,12 @@ class SpacesAroundListTest(_SpacesAroundDictListTupleTestImpl):
       index[a, b]
       []
       [v for v in [1,2,3] if v & 1] # yapf: disable
-      
+
       # yapf: disable
       [a,b,c]
       [4,5,]
       # yapf: enable
-      
+
       # List settings should not impact dicts or tuples
       {a: b}
       (1, 2)
@@ -2018,14 +2052,14 @@ class SpacesAroundTupleTest(_SpacesAroundDictListTupleTestImpl):
       (this_func or that_func)(3, 4)
       if (True and False): pass
       ()
-      
+
       (0, 1) # yapf: disable
 
       # yapf: disable
       (0, 1)
       (2, 3)
       # yapf: enable
-      
+
       # Tuple settings should not impact dicts or lists
       {a: b}
       [3, 4]
